@@ -4,19 +4,17 @@ require 'rbconfig'
 
 require 'mkmf'
 
-#if defined?(CFLAGS)
-#  if CFLAGS.index(CONFIG['CCDLFLAGS'])
-#    $CFLAGS = CFLAGS + ' ' + CONFIG['CCDLFLAGS']
-#  else
-#    $CFLAGS = CFLAGS
-#  end
-#else
-#  $CFLAGS = CONFIG['CFLAGS']
-#end
-#$LDFLAGS = CONFIG['LDFLAGS']
-#$LDFLAGS = "-L/usr/local/lib"
-#$LIBPATH.push(Config::CONFIG['libdir'])
-$LDFLAGS = "-Lc:/mingw/local/lib"
+if defined?(CFLAGS)
+  if CFLAGS.index(CONFIG['CCDLFLAGS'])
+    $CFLAGS = CFLAGS + ' ' + CONFIG['CCDLFLAGS']
+  else
+    $CFLAGS = CFLAGS
+  end
+else
+  $CFLAGS = CONFIG['CFLAGS']
+end
+$LDFLAGS = CONFIG['LDFLAGS']
+$LIBPATH.push(RbConfig::CONFIG['libdir'])
 
 def crash(str)
   printf(" extconf failure: %s\n", str)
