@@ -25,5 +25,11 @@ require 'libxml/sax_parser'
 require 'libxml/sax_callbacks'
 require 'libxml/xpath_object'
 
+#Schema Interface
+require 'libxml/schema'
+require 'libxml/schema/type'
+require 'libxml/schema/element'
+require 'libxml/schema/attribute'
+
 # Deprecated
 require 'libxml/properties'
\ No newline at end of file
